package de.opalpiraten.scenepainter.sys;
import java.io.File;

/**
 * Filter files by suffix
 */
public class SuffixFilter implements java.io.FileFilter {

  /**
   * Allow files with any suffix
   */
  public static final int ANY=0;
  
  /**
   * Only allow PNG files
   */
  public static final int PNG =1;
  
  /**
   * Only allow text files
   */
  public static final int TXT =2;
  
  /**
   * Only allow jar files
   */
  public static final int JAR=3;
  
  /**
   * Only allow XML files
   */
  public static final int XML=4;
  
  /**
   * Suffix to filter for
   */ 
  private int _suffix=ANY;
  
  /**
   * Allow directorytraversal
   */
  private boolean dir=true;
  
  /**
   * Filter for a suffix, directoy traversal is allowed
   */
  public SuffixFilter(int suffix) {
    super();
    _suffix=suffix;
    dir=true;
  }
  
  /**
   * Filter for suffix and allow/disallow to select directories
   * @param suffix the suffix to filter for
   * @param dir if set to true, directories of any name will pass
   * the filter, if set to false, directories will not pass the filter
   */
  public SuffixFilter(int suffix, boolean dir) {
    this(suffix);
    this.dir=dir;
  }
  
  public boolean accept(File f) {
    if (f.isDirectory()) {
      return dir;
    }
    String n = f.getName().toUpperCase();
    switch(_suffix) {
      case PNG: { if (n.endsWith(".PNG")) return true; break;}
      case TXT: { if (n.endsWith(".TXT")) return true; break;}
      case JAR: { if (n.endsWith(".JAR")) return true; break;}
      case XML: { if (n.endsWith(".XML")) return true; break;}
      
    }
    return false;
  }
  
  public String getDescription() {
    switch(_suffix) {
      case PNG: {return Dict.get("sys.suffixfilter.type.png");}
      case TXT: {return Dict.get("sys.suffixfilter.type.txt");}
      case JAR: {return Dict.get("sys.suffixfilter.type.jar");}
      case XML: {return Dict.get("sys.suffixfilter.type.xml");} 
      case ANY: {return Dict.get("sys.suffixfilter.type.any");}
      
    }
    return "All types";
  }
}
